def argv(name: int) -> str:
    """
    获取Icarus命令行参数\n
    :param name: 可以是整型也可以是字符串
    :return: 值
    """
    ...


def env(name: str, value: str) -> str:
    """
    获取Icarus环境变量\n
    :param name: 变量名
    :param value: 若此参数不存在则为获取，若此参数存在则为修改
    :return: 环境变量的值
    """
    ...


def shell_exec(cmd: str, args: list, visible: bool, cmd_dir: str) -> int:
    """
    在本地执行shell命令，以任务执行，非阻塞函数。\n
    ps.记得使用kill_task()终止\n
    :param cmd: 要执行的命令
    :param args: 命令行参数，类型为字符串列表，可省略
    :param visible: 执行结果是否可见，可省略，默认为可True
    :param cmd_dir: 执行命令的位置，可省略
    :return: 返回任务id
    """


def shell_fetch(tid: int, all_data: bool) -> (str, str):
    """
    获取shell执行的结果，返回标准输出与标准错误。\n
    :param tid: 任务序号
    :param all_data: 是否取回完整内容，可省略，默认为false
    :return: 两个字符串(标准输出,标准错误)
    """
    ...


def kill_task(tid: int) -> None:
    """
    终止任务。\n
    :param tid: 任务序号
    :return:
    """
    ...


def version() -> str:
    """
    获取ICARUS版本\n
    :return:
    """
    ...


def platform() -> str:
    """
    获取操作系统类型\n
    :return:
    """
    ...



class Vault:
    def __init__(self, identifications: list):
        """
        用于搜索和聚合数据\n
        :param identifications: 身份识别字段
        """
        ...

    def exact_search(self, conditions: dict) -> list:
        """
        精确搜索\n
        :param conditions: 指定对应字段的搜索内容
        :return:
        """
        ...

    def fuzzy_search(self, conditions: dict) -> list:
        """
        模糊搜索\n
        :param conditions: 指定对应字段的搜索内容
        :return:
        """
        ...

    def search(self, query: str) -> list:
        """
        直接搜索\n
        :param query: 要搜索的字符串
        :return:
        """
        ...

    def load_json(self, name: str, json_data: str, columns_map: dict) -> None:
        """
        载入json数据库\n
        :param name: 数据库名
        :param json_data: json数据
        :param columns_map: json字段与vault字段对应表
        :return:
        """
        ...



RED = 0
YELLOW = 0
BLACK = 0
GREEN = 0
MAGENTA = 0
CYAN = 0
WHITE = 0  # 可用颜色


def echo(something, color=WHITE, end="\n") -> None:
    """
    建议使用的输出\n
    :param something: 可以为任意类型，如果是字典，列表将输出他们在go中的结构
    :param color: 输出的颜色，可省略，默认为白色
    :param end: 输出的结尾，可省略，默认为换行符
    :return:
    """
    ...


def select(title: str, items: list) -> (int, str):
    """
    生成一个选择菜单，方向键选择，Enter确认 \n
    :param title: 标题
    :param items: 可选择的项目，字符串列表，若为空则不会阻塞
    :return: 返回选项序号与选项文本
    """
    ...


def match(left: str, right: str, text: str) -> list:
    """
    匹配文本中满足条件的全部文本（正则实现）\n
    e.g.
    \t echo(match("a", "c", "abc aqc")) \n
    \t result: ["b","q"] \n
    :param left: 左侧文本
    :param right: 右侧文本
    :param text: 需要匹配的文本
    :return: 返回包含结果的字符串列表
    """
    ...


def walkdir(path: str) -> list:
    """
    遍历文件夹\n
    :param path: 路径
    :return: 所有文件与文件夹
    """
    ...


def unzip(src: str, passwd: str, dest: str) -> None:
    """
    解压zip \n
    :param src: zip文件路径
    :param passwd: 密码，可省略，默认为空字符串
    :param dest: 目标路径，可省略，默认解压在zip同目录下
    :return:
    """
    ...


def notice(title: str, msg: str, png_path="", beep=False) -> bool:
    """
    弹出通知\n
    :param title: 标题
    :param msg: 消息
    :param png_path: 显示图片，可省略，默认为空字符串
    :param beep: 是否蜂鸣，可省略，默认false
    :return:
    """
    ...


def read_file(file_path: str) -> bytes:
    """
    读取文件\n
    :param file_path:
    :return:
    """
    ...


def save_file(file_path: str, content: str, cover=False) -> None:
    """
    保存文件\n
    :param file_path: 保存文件路径
    :param content: 内容
    :param cover: 是否覆盖，可省略，默认false
    :return:
    """
    ...


def input(prefix=">", color=WHITE, items={}) -> str:
    """
    带有补全提示的输入\n
    :param prefix: 前缀，可省略，默认为">"
    :param color: 颜色，前缀的颜色，可省略，默认为utils.WHITE
    :param items: 字典，键为提示词，值为描述。e.g.{"hello":"你好"}，可省略，默认空
    :return:
    """
    ...


def search(text: str, items: list, fuzzy=False) -> dict:
    """
    在字符串列表中搜索字符串\n
    :param text: 需要搜索的字符串
    :param items: 被搜索的字符串列表
    :param fuzzy: 是否启用模糊搜索，可省略，默认False
    :return: 返回一个字符串字典，值为搜索到的结果，键为结果所在行
    """
    ...


def exec_js(script: str) -> str:
    """
   执行JavaScript代码\n
   :param script: js代码
   :return:
   """
    ...


def exec_js_file(file_path: str) -> str:
    """
   执行js文件\n
   :param file_path: js文件路径
   :return:
   """
    ...



def bytes_to_string(b: bytes) -> str:
    """
    bytes转字符串\n
    :param b: 字节列表
    :return:
    """
    ...


def utf8(charset: str, text: str) -> str:
    """
    将其他字符集文本转换为utf8\n
    :param charset: 源文本使用的字符集
    :param text: 源文本
    :return:
    """
    ...


def json_loads(json_data: str) -> dict:
    """
    反序列化json对象\n
    :param json_data: 序列化的对象
    :return: 反序列化后的对象(dict或list)
    """
    ...


def json_dumps(obj: object) -> str:
    """
    序列化对象\n
    :param obj: 对象
    :return: 序列化后的对象
    """
    ...



class Container:
    def __init__(self):
        ...

    def image(self) -> str:
        """
        生成此容器的镜像\n
        :return:
        """
        ...

    def status(self) -> str:
        """
        容器状态 (容器已启动/停止/重启的时长)\n
        :return:
        """
        ...

    def state(self) -> str:
        """
        容器阶段 (created,running,restarting,removing,paused,exited,dead)\n
        :return:
        """
        ...

    def id(self) -> str:
        """
        容器完整id (短id为前12位)\n
        :return:
        """
        ...

    def port(self) -> dict:
        """
        所有端口映射信息\n
        :return:
        """
        ...


class Docker:
    """
    连接docker daemon
    """

    def __init__(self):
        ...

    def images(self) -> list:
        """
        获取已下载的镜像 \n
        :return: 返回包含镜像名的字符串列表
        """
        ...

    def containers(self) -> list:
        """
        获取所有容器 \n
        :return: 返回容器列表
        """
        return [Container]

    def start_container(self, cid: str) -> bool:
        """
        启动容器 \n
        :return: 返回是否执行成功
        """
        ...

    def stop_container(self, cid: str) -> bool:
        """
        停止容器 \n
        :return: 返回是否执行成功
        """
        ...

    def remove_container(self, cid: str) -> bool:
        """
        移除容器 \n
        :return: 返回是否执行成功
        """
        ...

    def exec(self, cid: str, cmd: str) -> bool:
        """
        在容器中执行命令 \n
        :return: 返回执行是否成功
        """
        ...



GET = "GET"
POST = "POST"


class Response:
    def status_code(self) -> int:
        """
        响应包状态码\n(如果为-1则表示请求过程发生错误，详细错误用text()方法查看。\n
        :return:
        """
        ...

    def headers(self) -> dict:
        """
        响应头\n
        存在多个值的响应头以列表储存。\n
        :return:
        """
        ...

    def text(self) -> str:
        """
        获取响应正文\n
        :return:
        """
        ...

    def content(self) -> bytes:
        """
        获取响应正文(bytes)\n
        :return:
        """
        ...


class Requester:
    def __init__(self, raw: str):
        """
        请求器可以通过规则生成请求，并按规则批量发送（尚不可用）\n
        :param raw: 基础请求包
        """
        ...

    def send(self, proxy_name: str, verify: bool) -> list:
        ...

    def set_proxy(self, name: str, proxy: dict) -> None:
        ...

    def set_verify(self, verify: bool):
        ...


def download(url: str, save_path: str, proxy_url: str) -> bool:
    """
    下载文件\n
    :param url: 文件url
    :param save_path: 文件保存路径，如果是文件将会写入文件。可省略，默认当前Icarus工作目录
    :param proxy_url: 代理url，可省略。e.g. http://127.0.0.1:7890 代理到本地clash
    :return: 下载是否成功
    """
    ...


def request(method: str, url: str, params: dict, data: str, headers: dict, verify: bool, proxy: dict) -> Response:
    """
    发送http请求\n
    :param method: GET,POST
    :param url: 目标url
    :param params: url参数，可省略
    :param data: post文本，可省略
    :param headers: 请求头,可省略
    :param verify: 是否验证https，可省略，默认为不验证
    :param proxy: 是否使用代理，可省略
    :return: Response
    """
    ...


def ssh(address: str, user: str, passwd_or_private_key_path: str) -> None:
    """
    启动一个交互式的shell\n
    :param address: 目标地址
    :param user: 用户名
    :param passwd_or_private_key_path: 密码或私钥文件路径
    :return:
    """
    ...


def ssh_run(address: str, user: str, passwd_or_private_key_path: str, command: str) -> None:
    """
    通过ssh执行命令并启动交互式\n
    :param address: 目标地址
    :param user: 用户名
    :param passwd_or_private_key_path: 密码或私钥文件路径
    :param command: 需要执行的命令
    :return:
    """
    ...


def ssh_exec(address: str, user: str, passwd_or_private_key_path: str, command: str) -> str:
    """
    通过ssh执行命令并立即断开连接\n
    :param address: 目标地址
    :param user: 用户名
    :param passwd_or_private_key_path: 密码或私钥文件路径
    :param command: 需要执行的命令
    :return: 返回命令执行输出
    """
    ...


class Tcp:
    def __init__(self, address: str):
        """
        建立tcp连接\n
        :param address: 地址
        """
        ...

    def send(self, data: str):
        """
        发送字符串\n
        :param data:
        :return:
        """
        ...

    def send_line(self, data: str):
        """
        发送字符串，但会在末尾加换行符\n
        :param data:
        :return:
        """
        ...

    def send_bytes(self, data: bytes):
        """
        发送字节数组\n
        :param data:
        :return:
        """
        ...

    def send_line_bytes(self, data: bytes):
        """
        发送字节数组，但会在末尾加换行符\n
        :param data:
        :return:
        """
        ...

    def recv(self) -> bytes:
        """
        接收所有数据\n
        :return: 返回字节数组
        """
        ...

    def recv_line(self) -> bytes:
        """
        接收数据到换行符停止\n
        :return: 返回字节数组
        """
        ...

    def interactive(self):
        """
        启用交互式收发数据\n
        :return:
        """
        ...

    def log(self):
        """
        显示收发日志\n
        :return:
        """
        ...



BASH = 0
TELNET = 1


def PUT_PUBLIC_KEY(key_or_key_path: str) -> str:
    """
    生成添加公钥命令\n
    :params key_or_key_path: 公钥字符串或公钥文件路径
    :return:
    """
    ...


def REVERSE_SHELL(address: str, mode: int) -> str:
    """
    生成反弹shell命令\n
    :param address: 接收shell的地址
    :param mode: payload模式，可省略，默认为cmds.BASH
    :return:
    """
    ...


def NC_LISTEN(port: int) -> str:
    """
    生成nc监听命令（tcp）\n
    :param port: 监听端口
    :return:
    """
    ...
